@@ -4,6 +4,7 @@ import threading
 import time
 import uuid
 import random
+from ctypes import c_int64
 from whatap import logging
 from whatap.conf.configure import Configure as conf
 from whatap.io.data_inputx import DataInputX
@@ -81,7 +82,7 @@ class TraceContextManager(object):
     def getId(cls):
         uuid1 = uuid.uuid1(TraceContextManager.node, TraceContextManager.clock_seq)
         key = (uuid1.int >> 64 & 0xffffffffffffffff) ^ (uuid1.int << 64 & 0xffffffffffffffff)
-        return key
+        return c_int64(key).value
 
     @classmethod
     def getCurrentKey(cls):
